@@ -1,4 +1,4 @@
-package WWW::NOS::Open::Article 0.101;    # -*- cperl; cperl-indent-level: 4 -*-
+package WWW::NOS::Open::Article v1.0.2;   # -*- cperl; cperl-indent-level: 4 -*-
 use strict;
 use warnings;
 
@@ -28,7 +28,7 @@ WWW::NOS::Open::Article - client side article in the Open NOS REST API.
 
 =head1 VERSION
 
-This document describes WWW::NOS::Open::Article version 0.101.
+This document describes WWW::NOS::Open::Article version v1.0.2.
 
 =head1 SYNOPSIS
 
